==> gmediaserver-0.11.0.tar.gz: gmediaserver-0.11.0/src/search-parser.h <==
/* A Bison parser, made by GNU Bison 2.1.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     T_EXISTS = 258,
     T_TRUE = 259,
     T_FALSE = 260,
     T_STRING = 261,
     T_PROPERTY = 262,
     T_DERIVED_FROM = 263,
     T_DOES_NOT_CONTAIN = 264,
     T_CONTAINS = 265,
     T_GE = 266,
     T_GT = 267,
     T_LE = 268,
     T_LT = 269,
     T_NE = 270,
     T_EQ = 271,
     T_OR = 272,
     T_AND = 273
   };
#endif
/* Tokens.  */
#define T_EXISTS 258
#define T_TRUE 259
#define T_FALSE 260
#define T_STRING 261
#define T_PROPERTY 262
#define T_DERIVED_FROM 263
#define T_DOES_NOT_CONTAIN 264
#define T_CONTAINS 265
#define T_GE 266
#define T_GT 267
#define T_LE 268
#define T_LT 269
#define T_NE 270
#define T_EQ 271
#define T_OR 272
#define T_AND 273




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 45 "search-parser.y"
typedef union YYSTYPE {
    char *str;
    int token;
    SearchExpr *expr;
    SearchCriteria *criteria;
    bool boolval;
} YYSTYPE;
/* Line 1447 of yacc.c.  */
#line 82 "search-parser.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

==> gmediaserver_0.12.0.orig.tar.gz: gmediaserver-0.12.0/src/search-parser.h <==
/* A Bison parser, made by GNU Bison 2.3.  */

/* Skeleton interface for Bison's Yacc-like parsers in C

   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     T_EXISTS = 258,
     T_TRUE = 259,
     T_FALSE = 260,
     T_STRING = 261,
     T_PROPERTY = 262,
     T_DERIVED_FROM = 263,
     T_DOES_NOT_CONTAIN = 264,
     T_CONTAINS = 265,
     T_GE = 266,
     T_GT = 267,
     T_LE = 268,
     T_LT = 269,
     T_NE = 270,
     T_EQ = 271,
     T_OR = 272,
     T_AND = 273
   };
#endif
/* Tokens.  */
#define T_EXISTS 258
#define T_TRUE 259
#define T_FALSE 260
#define T_STRING 261
#define T_PROPERTY 262
#define T_DERIVED_FROM 263
#define T_DOES_NOT_CONTAIN 264
#define T_CONTAINS 265
#define T_GE 266
#define T_GT 267
#define T_LE 268
#define T_LT 269
#define T_NE 270
#define T_EQ 271
#define T_OR 272
#define T_AND 273




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
#line 45 "search-parser.y"
{
    char *str;
    int token;
    SearchExpr *expr;
    SearchCriteria *criteria;
    bool boolval;
}
/* Line 1529 of yacc.c.  */
#line 93 "search-parser.h"
	YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif
